@@ -1,4 +1,4 @@
-//$Id: examplewindow.h,v 1.2 2004/10/10 21:49:33 murrayc Exp $ -*- c++ -*-
+//$Id: examplewindow.h,v 1.3 2006/05/09 16:51:33 murrayc Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2004 gtkmm development team
  *
@@ -35,7 +35,8 @@ protected:
   //Child widgets:
   Gtk::VBox m_VBox;
   MyContainer m_MyContainer;
-  Gtk::Button m_Button_One, m_Button_Two;
+  Gtk::Button m_Button_One;
+  Gtk::Label m_Button_Two;
   Gtk::HButtonBox m_ButtonBox;
   Gtk::Button m_Button_Quit;
 };
